@@ -2,9 +2,10 @@ from typing import (Callable,
                     Tuple)
 
 from ground.base import Relation
-from ground.hints import Point
+from ground.hints import (Point,
+                          Segment)
 
 QuaternaryPointPredicate = Callable[[Point, Point, Point, Point], bool]
 SegmentEndpoints = Tuple[Point, Point]
-SegmentPointRelater = Callable[[Point, Point, Point], bool]
-SegmentsRelater = Callable[[Point, Point, Point, Point], Relation]
+SegmentContainmentChecker = Callable[[Segment, Point], bool]
+SegmentsRelater = Callable[[Segment, Segment], Relation]
